@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import gtk
 import pango
+import gobject
 from gettext import gettext as _
 import gnomedvb
 from gnomedvb.ui.widgets.ChannelsStore import ChannelsStore
@@ -11,6 +12,25 @@ from gnomedvb.ui.timers.EditTimersDialog import EditTimersDialog
 from gnomedvb.ui.timers.TimerDialog import NoTimerCreatedDialog
 from gnomedvb.ui.preferences.Preferences import Preferences
 
+class HelpBox(gtk.EventBox):
+
+    def __init__(self):
+        gtk.EventBox.__init__(self)
+        self.modify_bg(gtk.STATE_NORMAL, self.style.base[gtk.STATE_NORMAL])
+                
+        frame = gtk.Frame()
+        frame.set_shadow_type(gtk.SHADOW_IN)
+        self.add(frame)
+        
+        self._helpview = gtk.Label()
+        self._helpview.set_ellipsize(pango.ELLIPSIZE_END)
+        self._helpview.set_alignment(0.50, 0.50)
+        frame.add(self._helpview)
+        
+    def set_markup(self, helptext):
+        self._helpview.set_markup("<span foreground='grey50'>%s</span>" % helptext)
+
+
 class ControlCenterWindow(gtk.Window):
 
     def __init__(self, model):
@@ -49,6 +69,7 @@ class ControlCenterWindow(gtk.Window):
         self.vbox_left.pack_start(groups_label, False)
         
         self.devgroupslist = gtk.ListStore(str, int)
+        self.devgroupslist.connect("row-inserted", self._on_devgroupslist_inserted)
         
         self.devgroupscombo = gtk.ComboBox(self.devgroupslist)
         self.devgroupscombo.connect("changed", self._on_devgroupscombo_changed)
@@ -73,19 +94,9 @@ class ControlCenterWindow(gtk.Window):
         
         self.schedulestore = None
                 
-        self.help_eventbox = gtk.EventBox()
-        self.help_eventbox.modify_bg(gtk.STATE_NORMAL, self.help_eventbox.style.base[gtk.STATE_NORMAL])
-                
-        frame = gtk.Frame()
-        frame.set_shadow_type(gtk.SHADOW_IN)
-        self.help_eventbox.add(frame)
-        
-        self.helpview = gtk.Label()
-        helptext = _("Choose a device group and channel on the left to view the program guide")
-        self.helpview.set_markup("<span foreground='grey50'>%s</span>" % helptext)
-        self.helpview.set_ellipsize(pango.ELLIPSIZE_END)
-        self.helpview.set_alignment(0.50, 0.50)
-        frame.add(self.helpview)
+        self.help_eventbox = HelpBox()
+        self.choose_group_text = _("Choose a device group and channel on the left to view the program guide")
+        self.create_group_text = _("No device groups are configured. Please go to preferences and create one.")
         self.hpaned.pack2(self.help_eventbox)
         
         self.scheduleview = ScheduleView()
@@ -99,10 +110,11 @@ class ControlCenterWindow(gtk.Window):
         self.scrolledschedule.show()
         
         self.get_device_groups()
-        
-        self.devgroupscombo.set_active(0)
-        self.channelsview.grab_focus()
-        
+        if len(self.devgroupslist) == 0:
+            self.help_eventbox.set_markup(self.create_group_text)
+        else:
+            self._select_first_group()
+      
     def __create_menu(self):
         ui = '''
         <menubar name="MenuBar">
@@ -115,6 +127,7 @@ class ControlCenterWindow(gtk.Window):
             <menuitem action="Preferences"/>
           </menu>
           <menu action="View">
+            <menuitem action="Refresh"/>
             <menuitem action="PrevDay"/>
             <menuitem action="NextDay"/>
             <separator/>
@@ -160,6 +173,8 @@ class ControlCenterWindow(gtk.Window):
         
         actiongroup = gtk.ActionGroup('View')
         actiongroup.add_actions([
+            ('Refresh', gtk.STOCK_REFRESH, _('Refresh'), None,
+             _('Refresh program guide'), self._on_refresh_clicked),
             ('PrevDay', None, _('Previous Day'), '<Control>B',
              _('Go to previous day'), self._on_button_prev_day_clicked),
             ('NextDay', None, _('Next Day'), '<Control>N',
@@ -198,6 +213,9 @@ class ControlCenterWindow(gtk.Window):
         self.timersitem.set_image(timers_image)
         self.timersitem.set_sensitive(False)
         
+        self.refresh_menuitem = uimanager.get_widget('/MenuBar/View/Refresh')
+        self.refresh_menuitem.set_sensitive(False)
+        
         self.prev_day_menuitem = uimanager.get_widget('/MenuBar/View/PrevDay')
         prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_MENU)
         prev_image.show()
@@ -237,6 +255,12 @@ class ControlCenterWindow(gtk.Window):
         sep.show()
         self.toolbar.insert(sep, 1)
         
+        self.refresh_button = gtk.ToolButton(gtk.STOCK_REFRESH)
+        self.refresh_button.connect("clicked", self._on_refresh_clicked)
+        self.refresh_button.set_tooltip_markup(_("Refresh program guide"))        
+        self.refresh_button.show()
+        self.toolbar.insert(self.refresh_button, 2)
+        
         prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_LARGE_TOOLBAR)
         prev_image.show()
         self.button_prev_day = gtk.ToolButton(icon_widget=prev_image, label=_("Previous Day"))
@@ -244,7 +268,7 @@ class ControlCenterWindow(gtk.Window):
         self.button_prev_day.set_tooltip_markup(_("Go to previous day"))
         self.button_prev_day.set_sensitive(False)
         self.button_prev_day.show()
-        self.toolbar.insert(self.button_prev_day, 2)
+        self.toolbar.insert(self.button_prev_day, 3)
         
         next_image = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD, gtk.ICON_SIZE_LARGE_TOOLBAR)
         next_image.show()
@@ -253,12 +277,19 @@ class ControlCenterWindow(gtk.Window):
         self.button_next_day.set_tooltip_markup(_("Go to next day"))
         self.button_next_day.set_sensitive(False)
         self.button_next_day.show()
-        self.toolbar.insert(self.button_next_day, 3)
+        self.toolbar.insert(self.button_next_day, 4)
          
     def get_device_groups(self):
         for group in self.manager.get_registered_device_groups():
             self._append_group(group)
             
+    def device_groups_reply(self, a):
+        print a
+       
+    def _select_first_group(self):
+        self.devgroupscombo.set_active(0)
+        self.channelsview.grab_focus()
+           
     def _append_group(self, group):
         self.devgroupslist.append([group["name"], group["id"]])
         self.channellists[group["id"]] = gnomedvb.DVBChannelListClient(group["id"])
@@ -280,11 +311,13 @@ class ControlCenterWindow(gtk.Window):
     def _reset_ui(self):
         self.channelsstore = None
         self.channelsview.set_model(None)
+        self._reset_schedule_view()
+        self._set_timers_sensitive(False)
+        
+    def _reset_schedule_view(self):
         self.schedulestore = None
         self.scheduleview.set_model(None)
         self._display_help_message()
-        self.button_display_timers.set_sensitive(False)
-        self.timersitem.set_sensitive(False)
 
     def _on_manager_changed(self, manager, group_id, change_type):
         if change_type == 0:
@@ -309,18 +342,24 @@ class ControlCenterWindow(gtk.Window):
             return sid
         else:
             return None
-
+    
     def _on_devgroupscombo_changed(self, combo):
         group_id = self._get_selected_group_id()
         if group_id != None:
-            self.button_display_timers.set_sensitive(True)
-            self.timersitem.set_sensitive(True)
+            self._set_timers_sensitive(True)
             
             self.channelsstore = ChannelsStore(group_id)
             self.channelsview.set_model(self.channelsstore)
+            
+            self._reset_schedule_view()
         else:
             self._reset_ui()
-        
+            
+    def _on_devgroupslist_inserted(self, model, path, aiter):
+        if len(model) == 1:
+            # Delay the call otherwise we get DBus errors
+            gobject.timeout_add(100, self._select_first_group)
+    
     def _on_channel_selected(self, treeselection):
         model, aiter = treeselection.get_selected()
         child = self.hpaned.get_child2()
@@ -336,6 +375,7 @@ class ControlCenterWindow(gtk.Window):
                 self.hpaned.pack2(self.scrolledschedule)
                 self._set_previous_day_sensitive(True)
                 self._set_next_day_sensitive(True)
+                self._set_refresh_sensitive(True)
         else:
             # Display help message if it isn't already displayed
             if child != self.help_eventbox:
@@ -347,6 +387,12 @@ class ControlCenterWindow(gtk.Window):
         self.hpaned.pack2(self.help_eventbox)
         self._set_previous_day_sensitive(False)
         self._set_next_day_sensitive(False)
+        self._set_refresh_sensitive(False)
+        
+        if len(self.devgroupslist) == 0:
+            self.help_eventbox.set_markup(self.create_group_text)
+        else:
+            self.help_eventbox.set_markup(self.choose_group_text)
                 
     def _set_next_day_sensitive(self, val):
         self.button_next_day.set_sensitive(val)
@@ -355,7 +401,15 @@ class ControlCenterWindow(gtk.Window):
     def _set_previous_day_sensitive(self, val):
         self.button_prev_day.set_sensitive(val)
         self.prev_day_menuitem.set_sensitive(val)
-            
+             
+    def _set_timers_sensitive(self, val):
+        self.button_display_timers.set_sensitive(val)
+        self.timersitem.set_sensitive(val)
+        
+    def _set_refresh_sensitive(self, val):
+       self.refresh_button.set_sensitive(val) 
+       self.refresh_menuitem.set_sensitive(val)
+       
     def _on_event_selected(self, treeview, event):
         if event.type == gtk.gdk._2BUTTON_PRESS:
             model, aiter = treeview.get_selection().get_selected()
@@ -383,6 +437,9 @@ class ControlCenterWindow(gtk.Window):
             edit = EditTimersDialog(group_id, self)
             edit.run()
             edit.destroy()
+            
+    def _on_refresh_clicked(self, button):
+        self.schedulestore.reload_all()
    
     def _on_button_prev_day_clicked(self, button):
         if self.schedulestore != None:
@@ -437,6 +494,7 @@ class ControlCenterWindow(gtk.Window):
 
     def _on_about_clicked(self, action):
         about = gtk.AboutDialog()
+        about.set_transient_for(self)
         #translators: These appear in the About dialog, usual format applies.
         about.set_translator_credits( _("translator-credits") )
         
