@@ -108,11 +108,11 @@ static gboolean dvb_channel_real_is_valid (DVBChannel* self) {
 		} else {
 			_tmp3 = gee_collection_get_size ((GeeCollection*) self->priv->_AudioPIDs) != 0;
 		}
-		_tmp0 = (_tmp3);
+		_tmp0 = _tmp3;
 	} else {
 		_tmp0 = FALSE;
 	}
-	return (_tmp0);
+	return _tmp0;
 }
 
 
@@ -131,7 +131,7 @@ gboolean dvb_channel_is_valid (DVBChannel* self) {
 static gboolean dvb_channel_real_on_same_transport_stream (DVBChannel* self, DVBChannel* channel) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (channel != NULL, FALSE);
-	return (self->priv->_Frequency == channel->priv->_Frequency);
+	return self->priv->_Frequency == channel->priv->_Frequency;
 }
 
 
