@@ -6,6 +6,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/list.h>
 #include <gst/gst.h>
 
 G_BEGIN_DECLS
@@ -40,6 +41,7 @@ struct _DVBChannelClass {
 };
 
 
+char* dvb_channel_get_audio_pids_string (DVBChannel* self);
 gboolean dvb_channel_is_valid (DVBChannel* self);
 gboolean dvb_channel_on_same_transport_stream (DVBChannel* self, DVBChannel* channel);
 void dvb_channel_setup_dvb_source (DVBChannel* self, GstElement* source);
@@ -56,10 +58,12 @@ guint* dvb_channel_get_LogicalChannelNumber (DVBChannel* self);
 void dvb_channel_set_LogicalChannelNumber (DVBChannel* self, guint* value);
 guint dvb_channel_get_VideoPID (DVBChannel* self);
 void dvb_channel_set_VideoPID (DVBChannel* self, guint value);
-guint dvb_channel_get_AudioPID (DVBChannel* self);
-void dvb_channel_set_AudioPID (DVBChannel* self, guint value);
+GeeList* dvb_channel_get_AudioPIDs (DVBChannel* self);
+void dvb_channel_set_AudioPIDs (DVBChannel* self, GeeList* value);
 guint dvb_channel_get_Frequency (DVBChannel* self);
 void dvb_channel_set_Frequency (DVBChannel* self, guint value);
+gboolean dvb_channel_get_Scrambled (DVBChannel* self);
+void dvb_channel_set_Scrambled (DVBChannel* self, gboolean value);
 DVBSchedule* dvb_channel_get_Schedule (DVBChannel* self);
 GType dvb_channel_get_type (void);
 
