@@ -28,7 +28,7 @@ static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* sel
 static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel (const char* line);
 static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (const char* line);
 static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char* line);
-static gint dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix);
+static gboolean dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix, gint* val);
 static void dvb_channel_list_reader_set_ChannelFile (DVBChannelListReader* self, GFile* value);
 static void dvb_channel_list_reader_set_Type (DVBChannelListReader* self, DVBAdapterType value);
 static gpointer dvb_channel_list_reader_parent_class = NULL;
@@ -122,9 +122,7 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 
 static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* self, const char* line) {
 	DVBChannel* c;
-	DVBChannel* _tmp3;
-	DVBChannel* _tmp4;
-	DVBChannel* _tmp5;
+	gboolean _tmp3;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	c = NULL;
@@ -156,15 +154,36 @@ static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* sel
 			break;
 		}
 	}
-	_tmp3 = NULL;
-	if ((dvb_channel_is_valid (c))) {
-		_tmp3 = c;
+	_tmp3 = FALSE;
+	if (c != NULL) {
+		_tmp3 = dvb_channel_is_valid (c);
 	} else {
-		_tmp3 = NULL;
+		_tmp3 = FALSE;
 	}
-	_tmp4 = NULL;
-	_tmp5 = NULL;
-	return (_tmp5 = (_tmp4 = _tmp3, (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4)), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp5);
+	if (_tmp3) {
+		return c;
+	} else {
+		char* _tmp5;
+		const char* _tmp8;
+		char* val;
+		DVBChannel* _tmp9;
+		_tmp5 = NULL;
+		if (c == NULL) {
+			char* _tmp6;
+			_tmp6 = NULL;
+			_tmp5 = (_tmp6 = g_strdup ("(null)"), _tmp5 = (g_free (_tmp5), NULL), _tmp6);
+		} else {
+			char* _tmp7;
+			_tmp7 = NULL;
+			_tmp5 = (_tmp7 = dvb_channel_to_string (c), _tmp5 = (g_free (_tmp5), NULL), _tmp7);
+		}
+		_tmp8 = NULL;
+		val = (_tmp8 = _tmp5, (_tmp8 == NULL) ? NULL : g_strdup (_tmp8));
+		g_warning ("ChannelListReader.vala:58: Channel is not valid: %s", val);
+		_tmp9 = NULL;
+		return (_tmp9 = NULL, _tmp5 = (g_free (_tmp5), NULL), val = (g_free (val), NULL), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp9);
+	}
+	(c == NULL) ? NULL : (c = (g_object_unref (c), NULL));
 }
 
 
@@ -184,9 +203,9 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 	char** fields;
 	gint i;
 	char* val;
+	gboolean failed;
 	char* _tmp3;
 	const char* _tmp2;
-	DVBTerrestrialChannel* _tmp4;
 	g_return_val_if_fail (line != NULL, NULL);
 	channel = dvb_terrestrial_channel_new ();
 	_tmp1 = NULL;
@@ -194,6 +213,7 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 	fields = (_tmp1 = _tmp0 = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0), fields_size = fields_length1, _tmp1);
 	i = 0;
 	val = NULL;
+	failed = FALSE;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	while ((val = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), val = (g_free (val), NULL), _tmp3)) != NULL) {
@@ -201,7 +221,7 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:76: Bad UTF-8 encoded channel name");
+				g_warning ("ChannelListReader.vala:83: Bad UTF-8 encoded channel name");
 				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
@@ -209,28 +229,84 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 				dvb_channel_set_Frequency ((DVBChannel*) channel, (guint) atoi (val));
 			} else {
 				if (i == 2) {
-					dvb_terrestrial_channel_set_Inversion (channel, (DVBDvbSrcInversion) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
+					gint eval;
+					eval = 0;
+					if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_", &eval)) {
+						dvb_terrestrial_channel_set_Inversion (channel, (DVBDvbSrcInversion) eval);
+					} else {
+						failed = TRUE;
+						break;
+					}
 				} else {
 					if (i == 3) {
-						dvb_terrestrial_channel_set_Bandwidth (channel, (DVBDvbSrcBandwidth) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_BANDWIDTH, val, "DVB_DVB_SRC_BANDWIDTH_"));
+						gint eval;
+						eval = 0;
+						if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_BANDWIDTH, val, "DVB_DVB_SRC_BANDWIDTH_", &eval)) {
+							dvb_terrestrial_channel_set_Bandwidth (channel, (DVBDvbSrcBandwidth) eval);
+						} else {
+							failed = TRUE;
+							break;
+						}
 					} else {
 						if (i == 4) {
-							dvb_terrestrial_channel_set_CodeRateHP (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+							gint eval;
+							eval = 0;
+							if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_", &eval)) {
+								dvb_terrestrial_channel_set_CodeRateHP (channel, (DVBDvbSrcCodeRate) eval);
+							} else {
+								failed = TRUE;
+								break;
+							}
 						} else {
 							if (i == 5) {
-								dvb_terrestrial_channel_set_CodeRateLP (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+								gint eval;
+								eval = 0;
+								if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_", &eval)) {
+									dvb_terrestrial_channel_set_CodeRateLP (channel, (DVBDvbSrcCodeRate) eval);
+								} else {
+									failed = TRUE;
+									break;
+								}
 							} else {
 								if (i == 6) {
-									dvb_terrestrial_channel_set_Constellation (channel, (DVBDvbSrcModulation) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
+									gint eval;
+									eval = 0;
+									if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_", &eval)) {
+										dvb_terrestrial_channel_set_Constellation (channel, (DVBDvbSrcModulation) eval);
+									} else {
+										failed = TRUE;
+										break;
+									}
 								} else {
 									if (i == 7) {
-										dvb_terrestrial_channel_set_TransmissionMode (channel, (DVBDvbSrcTransmissionMode) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_TRANSMISSION_MODE, val, "DVB_DVB_SRC_TRANSMISSION_MODE_"));
+										gint eval;
+										eval = 0;
+										if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_TRANSMISSION_MODE, val, "DVB_DVB_SRC_TRANSMISSION_MODE_", &eval)) {
+											dvb_terrestrial_channel_set_TransmissionMode (channel, (DVBDvbSrcTransmissionMode) eval);
+										} else {
+											failed = TRUE;
+											break;
+										}
 									} else {
 										if (i == 8) {
-											dvb_terrestrial_channel_set_GuardInterval (channel, (DVBDvbSrcGuard) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_GUARD, val, "DVB_DVB_SRC_GUARD_"));
+											gint eval;
+											eval = 0;
+											if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_GUARD, val, "DVB_DVB_SRC_GUARD_", &eval)) {
+												dvb_terrestrial_channel_set_GuardInterval (channel, (DVBDvbSrcGuard) eval);
+											} else {
+												failed = TRUE;
+												break;
+											}
 										} else {
 											if (i == 9) {
-												dvb_terrestrial_channel_set_Hierarchy (channel, (DVBDvbSrcHierarchy) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_HIERARCHY, val, "DVB_DVB_SRC_HIERARCHY_"));
+												gint eval;
+												eval = 0;
+												if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_HIERARCHY, val, "DVB_DVB_SRC_HIERARCHY_", &eval)) {
+													dvb_terrestrial_channel_set_Hierarchy (channel, (DVBDvbSrcHierarchy) eval);
+												} else {
+													failed = TRUE;
+													break;
+												}
 											} else {
 												if (i == 10) {
 													dvb_channel_set_VideoPID ((DVBChannel*) channel, (guint) atoi (val));
@@ -255,8 +331,18 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 		}
 		i++;
 	}
-	_tmp4 = NULL;
-	return (_tmp4 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+	if (failed) {
+		DVBTerrestrialChannel* _tmp4;
+		_tmp4 = NULL;
+		return (_tmp4 = NULL, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+	} else {
+		DVBTerrestrialChannel* _tmp5;
+		_tmp5 = NULL;
+		return (_tmp5 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp5);
+	}
+	(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
+	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+	val = (g_free (val), NULL);
 }
 
 
@@ -291,7 +377,7 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (con
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:137: Bad UTF-8 encoded channel name");
+				g_warning ("ChannelListReader.vala:192: Bad UTF-8 encoded channel name");
 				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
@@ -347,9 +433,9 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 	char** fields;
 	gint i;
 	char* val;
+	gboolean failed;
 	char* _tmp3;
 	const char* _tmp2;
-	DVBCableChannel* _tmp4;
 	g_return_val_if_fail (line != NULL, NULL);
 	channel = dvb_cable_channel_new ();
 	_tmp1 = NULL;
@@ -357,6 +443,7 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 	fields = (_tmp1 = _tmp0 = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0), fields_size = fields_length1, _tmp1);
 	i = 0;
 	val = NULL;
+	failed = FALSE;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	while ((val = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), val = (g_free (val), NULL), _tmp3)) != NULL) {
@@ -364,7 +451,7 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:182: Bad UTF-8 encoded channel name");
+				g_warning ("ChannelListReader.vala:238: Bad UTF-8 encoded channel name");
 				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
@@ -372,16 +459,37 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 				dvb_channel_set_Frequency ((DVBChannel*) channel, (guint) atoi (val));
 			} else {
 				if (i == 2) {
-					dvb_cable_channel_set_Inversion (channel, (DVBDvbSrcInversion) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
+					gint eval;
+					eval = 0;
+					if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_", &eval)) {
+						dvb_cable_channel_set_Inversion (channel, (DVBDvbSrcInversion) eval);
+					} else {
+						failed = TRUE;
+						break;
+					}
 				} else {
 					if (i == 3) {
 						dvb_cable_channel_set_SymbolRate (channel, (guint) atoi (val));
 					} else {
 						if (i == 4) {
-							dvb_cable_channel_set_CodeRate (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+							gint eval;
+							eval = 0;
+							if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_", &eval)) {
+								dvb_cable_channel_set_CodeRate (channel, (DVBDvbSrcCodeRate) eval);
+							} else {
+								failed = TRUE;
+								break;
+							}
 						} else {
 							if (i == 5) {
-								dvb_cable_channel_set_Modulation (channel, (DVBDvbSrcModulation) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
+								gint eval;
+								eval = 0;
+								if (dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_", &eval)) {
+									dvb_cable_channel_set_Modulation (channel, (DVBDvbSrcModulation) eval);
+								} else {
+									failed = TRUE;
+									break;
+								}
 							} else {
 								if (i == 6) {
 									dvb_channel_set_VideoPID ((DVBChannel*) channel, (guint) atoi (val));
@@ -402,18 +510,28 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 		}
 		i++;
 	}
-	_tmp4 = NULL;
-	return (_tmp4 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+	if (failed) {
+		DVBCableChannel* _tmp4;
+		_tmp4 = NULL;
+		return (_tmp4 = NULL, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+	} else {
+		DVBCableChannel* _tmp5;
+		_tmp5 = NULL;
+		return (_tmp5 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp5);
+	}
+	(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
+	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+	val = (g_free (val), NULL);
 }
 
 
-static gint dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix) {
+static gboolean dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix, gint* val) {
 	char* _tmp0;
-	gint _tmp1;
-	g_return_val_if_fail (name != NULL, 0);
-	g_return_val_if_fail (prefix != NULL, 0);
+	gboolean _tmp1;
+	g_return_val_if_fail (name != NULL, FALSE);
+	g_return_val_if_fail (prefix != NULL, FALSE);
 	_tmp0 = NULL;
-	return (_tmp1 = dvb_utils_get_value_by_name_from_enum (enumtype, _tmp0 = g_strconcat (prefix, name, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	return (_tmp1 = dvb_utils_get_value_by_name_from_enum (enumtype, _tmp0 = g_strconcat (prefix, name, NULL), &(*val)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
