@@ -9,10 +9,10 @@
 struct _DVBDevicePrivate {
 	guint _Adapter;
 	guint _Frontend;
-	DVBAdapterType _Type;
-	char* _Name;
 	DVBChannelList* _Channels;
 	GFile* _RecordingsDirectory;
+	char* adapter_name;
+	DVBAdapterType adapter_type;
 };
 
 #define DVB_DEVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_DEVICE, DVBDevicePrivate))
@@ -26,12 +26,9 @@ enum  {
 	DVB_DEVICE_RECORDINGS_DIRECTORY
 };
 #define DVB_DEVICE_PRIME 31
-static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type);
-static char* dvb_device_getAdapterName (guint adapter, gboolean get_name);
+static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter, gboolean get_type);
 static void dvb_device_set_Adapter (DVBDevice* self, guint value);
 static void dvb_device_set_Frontend (DVBDevice* self, guint value);
-static void dvb_device_set_Type (DVBDevice* self, DVBAdapterType value);
-static void dvb_device_set_Name (DVBDevice* self, const char* value);
 static gpointer dvb_device_parent_class = NULL;
 static void dvb_device_finalize (GObject* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -42,7 +39,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 GType dvb_adapter_type_get_type (void) {
 	static GType dvb_adapter_type_type_id = 0;
 	if (G_UNLIKELY (dvb_adapter_type_type_id == 0)) {
-		static const GEnumValue values[] = {{DVB_ADAPTER_TYPE_DVB_T, "DVB_ADAPTER_TYPE_DVB_T", "dvb-t"}, {DVB_ADAPTER_TYPE_DVB_S, "DVB_ADAPTER_TYPE_DVB_S", "dvb-s"}, {DVB_ADAPTER_TYPE_DVB_C, "DVB_ADAPTER_TYPE_DVB_C", "dvb-c"}, {DVB_ADAPTER_TYPE_UNKNOWN, "DVB_ADAPTER_TYPE_UNKNOWN", "unknown"}, {0, NULL, NULL}};
+		static const GEnumValue values[] = {{DVB_ADAPTER_TYPE_UNKNOWN, "DVB_ADAPTER_TYPE_UNKNOWN", "unknown"}, {DVB_ADAPTER_TYPE_DVB_T, "DVB_ADAPTER_TYPE_DVB_T", "dvb-t"}, {DVB_ADAPTER_TYPE_DVB_S, "DVB_ADAPTER_TYPE_DVB_S", "dvb-s"}, {DVB_ADAPTER_TYPE_DVB_C, "DVB_ADAPTER_TYPE_DVB_C", "dvb-c"}, {0, NULL, NULL}};
 		dvb_adapter_type_type_id = g_enum_register_static ("DVBAdapterType", values);
 	}
 	return dvb_adapter_type_type_id;
@@ -52,9 +49,8 @@ GType dvb_adapter_type_get_type (void) {
 DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint frontend, gboolean get_type_and_name) {
 	GParameter * __params;
 	GParameter * __params_it;
-	char* _tmp0;
 	DVBDevice * self;
-	__params = g_new0 (GParameter, 4);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "Adapter";
 	g_value_init (&__params_it->value, G_TYPE_UINT);
@@ -64,17 +60,8 @@ DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint fronten
 	g_value_init (&__params_it->value, G_TYPE_UINT);
 	g_value_set_uint (&__params_it->value, frontend);
 	__params_it++;
-	__params_it->name = "Type";
-	g_value_init (&__params_it->value, DVB_TYPE_ADAPTER_TYPE);
-	g_value_set_enum (&__params_it->value, dvb_device_getAdapterType (adapter, get_type_and_name));
-	__params_it++;
-	_tmp0 = NULL;
-	__params_it->name = "Name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _tmp0 = dvb_device_getAdapterName (adapter, get_type_and_name));
-	__params_it++;
-	_tmp0 = (g_free (_tmp0), NULL);
 	self = g_object_newv (object_type, __params_it - __params, __params);
+	dvb_device_setAdapterTypeAndName (self, adapter, get_type_and_name);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -118,7 +105,7 @@ gboolean dvb_device_equal (DVBDevice* dev1, DVBDevice* dev2) {
 	} else {
 		_tmp2 = FALSE;
 	}
-	return (_tmp2);
+	return _tmp2;
 }
 
 
@@ -146,14 +133,14 @@ gboolean dvb_device_is_busy (DVBDevice* self) {
 	dvbsrc = gst_element_factory_make ("dvbsrc", "text_dvbsrc");
 	if (dvbsrc == NULL) {
 		gboolean _tmp0;
-		g_critical ("Device.vala:60: Could not create dvbsrc element");
+		g_critical ("Device.vala:65: Could not create dvbsrc element");
 		return (_tmp0 = TRUE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp0);
 	}
 	g_object_set ((GObject*) dvbsrc, "adapter", self->priv->_Adapter, NULL);
 	g_object_set ((GObject*) dvbsrc, "frontend", self->priv->_Frontend, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
 	_tmp1 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
+	gst_bin_add (GST_BIN (pipeline), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	busy_val = FALSE;
@@ -182,7 +169,7 @@ gboolean dvb_device_is_busy (DVBDevice* self) {
 			_tmp3 = NULL;
 			(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
 			debug_text = (_tmp6 = _tmp5, debug_text = (g_free (debug_text), NULL), _tmp6);
-			g_debug ("Device.vala:82: Error tuning: %s; %s", gerror->message, debug_text);
+			g_debug ("Device.vala:87: Error tuning: %s; %s", gerror->message, debug_text);
 			busy_val = TRUE;
 			(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 			debug_text = (g_free (debug_text), NULL);
@@ -194,27 +181,31 @@ gboolean dvb_device_is_busy (DVBDevice* self) {
 }
 
 
-static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type) {
+static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter, gboolean get_type) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
 	GstElement* _tmp2;
 	GstBus* bus;
+	gboolean success;
 	char* adapter_type;
+	gboolean _tmp10;
+	g_return_val_if_fail (self != NULL, FALSE);
 	if (!get_type) {
-		return DVB_ADAPTER_TYPE_UNKNOWN;
+		return TRUE;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
 	if (dvbsrc == NULL) {
-		DVBAdapterType _tmp1;
-		g_critical ("Device.vala:98: Could not create dvbsrc element");
-		return (_tmp1 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+		gboolean _tmp1;
+		g_critical ("Device.vala:103: Could not create dvbsrc element");
+		return (_tmp1 = FALSE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
 	}
 	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
-	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
+	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new ("type_name"));
 	_tmp2 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
+	gst_bin_add (GST_BIN (pipeline), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
+	success = FALSE;
 	adapter_type = NULL;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
@@ -231,8 +222,12 @@ static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_typ
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
 				char* _tmp4;
+				char* _tmp5;
 				_tmp4 = NULL;
 				adapter_type = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "type")), adapter_type = (g_free (adapter_type), NULL), _tmp4);
+				_tmp5 = NULL;
+				self->priv->adapter_name = (_tmp5 = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL), _tmp5);
+				success = TRUE;
 				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
 			}
@@ -240,19 +235,19 @@ static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_typ
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
+				char* _tmp9;
 				char* _tmp8;
-				char* _tmp7;
+				GError* _tmp7;
 				GError* _tmp6;
-				GError* _tmp5;
 				gerror = NULL;
 				debug = NULL;
+				_tmp9 = NULL;
 				_tmp8 = NULL;
 				_tmp7 = NULL;
 				_tmp6 = NULL;
-				_tmp5 = NULL;
-				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
-				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
-				g_critical ("Device.vala:125: %s %s", gerror->message, debug);
+				(gst_message_parse_error (msg, &_tmp6, &_tmp8), gerror = (_tmp7 = _tmp6, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp7));
+				debug = (_tmp9 = _tmp8, debug = (g_free (debug), NULL), _tmp9);
+				g_critical ("Device.vala:133: %s %s", gerror->message, debug);
 				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
 			}
@@ -261,99 +256,19 @@ static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_typ
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
 	if (_vala_strcmp0 (adapter_type, "DVB-T") == 0) {
-		DVBAdapterType _tmp9;
-		return (_tmp9 = DVB_ADAPTER_TYPE_DVB_T, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp9);
+		self->priv->adapter_type = DVB_ADAPTER_TYPE_DVB_T;
 	} else {
 		if (_vala_strcmp0 (adapter_type, "DVB-S") == 0) {
-			DVBAdapterType _tmp10;
-			return (_tmp10 = DVB_ADAPTER_TYPE_DVB_S, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp10);
+			self->priv->adapter_type = DVB_ADAPTER_TYPE_DVB_S;
 		} else {
 			if (_vala_strcmp0 (adapter_type, "DVB-C") == 0) {
-				DVBAdapterType _tmp11;
-				return (_tmp11 = DVB_ADAPTER_TYPE_DVB_C, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp11);
+				self->priv->adapter_type = DVB_ADAPTER_TYPE_DVB_C;
 			} else {
-				DVBAdapterType _tmp12;
-				return (_tmp12 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp12);
+				self->priv->adapter_type = DVB_ADAPTER_TYPE_UNKNOWN;
 			}
 		}
 	}
-	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
-	(pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL));
-	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
-	adapter_type = (g_free (adapter_type), NULL);
-}
-
-
-static char* dvb_device_getAdapterName (guint adapter, gboolean get_name) {
-	GstElement* dvbsrc;
-	GstElement* pipeline;
-	GstElement* _tmp2;
-	GstBus* bus;
-	char* adapter_name;
-	char* _tmp9;
-	if (!get_name) {
-		return NULL;
-	}
-	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
-	if (dvbsrc == NULL) {
-		char* _tmp1;
-		g_critical ("Device.vala:142: Could not create dvbsrc element");
-		_tmp1 = NULL;
-		return (_tmp1 = NULL, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
-	}
-	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
-	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
-	_tmp2 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
-	gst_element_set_state (pipeline, GST_STATE_READY);
-	bus = gst_element_get_bus (pipeline);
-	adapter_name = NULL;
-	while (gst_bus_have_pending (bus)) {
-		GstMessage* msg;
-		gboolean _tmp3;
-		msg = gst_bus_pop (bus);
-		_tmp3 = FALSE;
-		if (msg->type == GST_MESSAGE_ELEMENT) {
-			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
-		} else {
-			_tmp3 = FALSE;
-		}
-		if (_tmp3) {
-			const GstStructure* structure;
-			structure = msg->structure;
-			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				char* _tmp4;
-				_tmp4 = NULL;
-				adapter_name = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), adapter_name = (g_free (adapter_name), NULL), _tmp4);
-				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
-				break;
-			}
-		} else {
-			if (msg->type == GST_MESSAGE_ERROR) {
-				GError* gerror;
-				char* debug;
-				char* _tmp8;
-				char* _tmp7;
-				GError* _tmp6;
-				GError* _tmp5;
-				gerror = NULL;
-				debug = NULL;
-				_tmp8 = NULL;
-				_tmp7 = NULL;
-				_tmp6 = NULL;
-				_tmp5 = NULL;
-				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
-				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
-				g_critical ("Device.vala:169: %s %s", gerror->message, debug);
-				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
-				debug = (g_free (debug), NULL);
-			}
-		}
-		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
-	}
-	gst_element_set_state (pipeline, GST_STATE_NULL);
-	_tmp9 = NULL;
-	return (_tmp9 = adapter_name, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp9);
+	return (_tmp10 = success, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp10);
 }
 
 
@@ -385,31 +300,13 @@ static void dvb_device_set_Frontend (DVBDevice* self, guint value) {
 
 DVBAdapterType dvb_device_get_Type (DVBDevice* self) {
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_Type;
-}
-
-
-static void dvb_device_set_Type (DVBDevice* self, DVBAdapterType value) {
-	g_return_if_fail (self != NULL);
-	self->priv->_Type = value;
-	g_object_notify ((GObject *) self, "Type");
+	return self->priv->adapter_type;
 }
 
 
 const char* dvb_device_get_Name (DVBDevice* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Name;
-}
-
-
-static void dvb_device_set_Name (DVBDevice* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
-	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp2);
-	g_object_notify ((GObject *) self, "Name");
+	return self->priv->adapter_name;
 }
 
 
@@ -487,12 +384,6 @@ static void dvb_device_set_property (GObject * object, guint property_id, const
 		case DVB_DEVICE_FRONTEND:
 		dvb_device_set_Frontend (self, g_value_get_uint (value));
 		break;
-		case DVB_DEVICE_TYPE:
-		dvb_device_set_Type (self, g_value_get_enum (value));
-		break;
-		case DVB_DEVICE_NAME:
-		dvb_device_set_Name (self, g_value_get_string (value));
-		break;
 		case DVB_DEVICE_CHANNELS:
 		dvb_device_set_Channels (self, g_value_get_object (value));
 		break;
@@ -514,8 +405,8 @@ static void dvb_device_class_init (DVBDeviceClass * klass) {
 	G_OBJECT_CLASS (klass)->finalize = dvb_device_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_ADAPTER, g_param_spec_uint ("Adapter", "Adapter", "Adapter", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_FRONTEND, g_param_spec_uint ("Frontend", "Frontend", "Frontend", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_CHANNELS, g_param_spec_object ("Channels", "Channels", "Channels", DVB_TYPE_CHANNEL_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_RECORDINGS_DIRECTORY, g_param_spec_object ("RecordingsDirectory", "RecordingsDirectory", "RecordingsDirectory", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -529,9 +420,9 @@ static void dvb_device_instance_init (DVBDevice * self) {
 static void dvb_device_finalize (GObject* obj) {
 	DVBDevice * self;
 	self = DVB_DEVICE (obj);
-	self->priv->_Name = (g_free (self->priv->_Name), NULL);
 	(self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL));
 	(self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL));
+	self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL);
 	G_OBJECT_CLASS (dvb_device_parent_class)->finalize (obj);
 }
 
