@@ -98,7 +98,7 @@ gboolean dvb_event_has_expired (DVBEvent* self) {
 	current_utc.tm_isdst = -1;
 	current_time = (gint64) mktime (&current_utc);
 	end_timestamp = dvb_event_get_end_timestamp (self);
-	return (end_timestamp < current_time);
+	return end_timestamp < current_time;
 }
 
 
@@ -117,7 +117,7 @@ gboolean dvb_event_is_running (DVBEvent* self) {
 	timestamp_start = (gint64) timegm (&time_start);
 	if ((timestamp_now - timestamp_start) >= 0) {
 		/* Has started, check if it's still running*/
-		return (!dvb_event_has_expired (self));
+		return !dvb_event_has_expired (self);
 	} else {
 		/* Has not started, yet*/
 		return FALSE;
@@ -143,7 +143,7 @@ char* dvb_event_to_string (DVBEvent* self) {
 			char* _tmp3;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			text = (_tmp4 = g_strconcat (text, _tmp3 = (g_strdup_printf ("%s ", ((DVBEventAudioComponent*) g_slist_nth_data (self->audio_components, (guint) i))->type)), NULL), text = (g_free (text), NULL), _tmp4);
+			text = (_tmp4 = g_strconcat (text, _tmp3 = g_strdup_printf ("%s ", ((DVBEventAudioComponent*) g_slist_nth_data (self->audio_components, (guint) i))->type), NULL), text = (g_free (text), NULL), _tmp4);
 			_tmp3 = (g_free (_tmp3), NULL);
 		}
 	}
@@ -267,7 +267,7 @@ gboolean dvb_event_equal (DVBEvent* event1, DVBEvent* event2) {
 	if (_tmp0) {
 		return FALSE;
 	}
-	return (event1->id == event2->id);
+	return event1->id == event2->id;
 }
 
 
