@@ -39,7 +39,9 @@ guint _dynamic_RequestName0 (DBusGProxy* self, const char* param1, guint param2,
 static gboolean main_start_manager (void);
 static gboolean main_start_recordings_store (guint32 minimum_id);
 static void main_on_exit (gint signum);
+static void main_log_func (const char* log_domain, GLogLevelFlags log_levels, const char* message);
 static void _main_on_exit_cutils_signal_signal_handler (gint signum);
+static void _main_log_func_glog_func (const char* log_domain, GLogLevelFlags log_levels, const char* message, gpointer self);
 static void main_instance_init (Main * self);
 static void _vala_dbus_register_object (DBusConnection* connection, const char* path, void* object);
 
@@ -169,11 +171,29 @@ static void main_on_exit (gint signum) {
 }
 
 
+static void main_log_func (const char* log_domain, GLogLevelFlags log_levels, const char* message) {
+	g_return_if_fail (message != NULL);
+	if (main_has_debug) {
+		g_log_default_handler (log_domain, log_levels, message, NULL);
+	}
+}
+
+
+gboolean main_get_disable_epg_scanner (void) {
+	return main_disable_epg_scanner;
+}
+
+
 static void _main_on_exit_cutils_signal_signal_handler (gint signum) {
 	main_on_exit (signum);
 }
 
 
+static void _main_log_func_glog_func (const char* log_domain, GLogLevelFlags log_levels, const char* message, gpointer self) {
+	main_log_func (log_domain, log_levels, message);
+}
+
+
 gint main_main (char** args, int args_length1) {
 	GError * inner_error;
 	GOptionContext* context;
@@ -182,9 +202,9 @@ gint main_main (char** args, int args_length1) {
 	DVBTimersStore* timers_store;
 	DVBConfigStore* config_store;
 	GeeList* device_groups;
-	GstRTSPServer* _tmp5;
-	DVBMediaMapping* _tmp6;
-	gint _tmp7;
+	GstRTSPServer* _tmp6;
+	DVBMediaMapping* _tmp7;
+	gint _tmp8;
 	inner_error = NULL;
 	signal (SIGINT, _main_on_exit_cutils_signal_signal_handler);
 	signal (SIGTERM, _main_on_exit_cutils_signal_signal_handler);
@@ -226,6 +246,7 @@ gint main_main (char** args, int args_length1) {
 		fprintf (stdout, " %s\n", PACKAGE_VERSION);
 		return (_tmp1 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp1);
 	}
+	g_log_set_handler (NULL, (G_LOG_LEVEL_DEBUG | G_LOG_FLAG_FATAL) | G_LOG_FLAG_RECURSION, _main_log_func_glog_func, NULL);
 	/* Creating a GLib main loop with a default context*/
 	_tmp2 = NULL;
 	main_mainloop = (_tmp2 = g_main_loop_new (NULL, FALSE), (main_mainloop == NULL) ? NULL : (main_mainloop = (g_main_loop_unref (main_mainloop), NULL)), _tmp2);
@@ -246,12 +267,11 @@ gint main_main (char** args, int args_length1) {
 			DVBDeviceGroup* device_group;
 			device_group = (DVBDeviceGroup*) gee_iterator_get (_device_group_it);
 			if (dvb_manager_add_device_group (main_manager, device_group)) {
+				DVBRecorder* _tmp4;
 				DVBRecorder* rec;
 				GeeList* timers;
-				if (!main_disable_epg_scanner) {
-					dvb_manager_create_and_start_epg_scanner (main_manager, device_group);
-				}
-				rec = dvb_manager_get_recorder_for_device_group (main_manager, device_group);
+				_tmp4 = NULL;
+				rec = (_tmp4 = dvb_device_group_get_recorder (device_group), (_tmp4 == NULL) ? NULL : g_object_ref (_tmp4));
 				/* Restore timers*/
 				timers = dvb_timers_store_get_all_timers_of_device_group (timers_store, device_group);
 				{
@@ -280,18 +300,18 @@ gint main_main (char** args, int args_length1) {
 	timers_store = NULL;
 	config_store = NULL;
 	if (!main_start_recordings_store (max_id)) {
-		gint _tmp4;
-		return (_tmp4 = -1, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), (device_groups == NULL) ? NULL : (device_groups = (g_object_unref (device_groups), NULL)), _tmp4);
+		gint _tmp5;
+		return (_tmp5 = -1, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), (device_groups == NULL) ? NULL : (device_groups = (g_object_unref (device_groups), NULL)), _tmp5);
 	}
-	_tmp5 = NULL;
-	main_server = (_tmp5 = gst_rtsp_server_new (), (main_server == NULL) ? NULL : (main_server = (g_object_unref (main_server), NULL)), _tmp5);
 	_tmp6 = NULL;
-	gst_rtsp_server_set_media_mapping (main_server, (GstRTSPMediaMapping*) (_tmp6 = dvb_media_mapping_new ()));
-	(_tmp6 == NULL) ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL));
+	main_server = (_tmp6 = gst_rtsp_server_new (), (main_server == NULL) ? NULL : (main_server = (g_object_unref (main_server), NULL)), _tmp6);
+	_tmp7 = NULL;
+	gst_rtsp_server_set_media_mapping (main_server, (GstRTSPMediaMapping*) (_tmp7 = dvb_media_mapping_new ()));
+	(_tmp7 == NULL) ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL));
 	gst_rtsp_server_attach (main_server, NULL);
 	/* Start GLib mainloop*/
 	g_main_loop_run (main_mainloop);
-	return (_tmp7 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), (device_groups == NULL) ? NULL : (device_groups = (g_object_unref (device_groups), NULL)), _tmp7);
+	return (_tmp8 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), (device_groups == NULL) ? NULL : (device_groups = (g_object_unref (device_groups), NULL)), _tmp8);
 }
 
 
