@@ -29,6 +29,7 @@ enum  {
 static gpointer dvb_recording_parent_class = NULL;
 static void dvb_recording_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -106,6 +107,7 @@ void dvb_recording_save_to_disk (DVBRecording* self, GError** error) {
 
 char* dvb_recording_serialize (DVBRecording* self) {
 	guint* _tmp1;
+	gint started_size;
 	gint started_length1;
 	gint _tmp0;
 	guint* started;
@@ -116,15 +118,15 @@ char* dvb_recording_serialize (DVBRecording* self) {
 	char* _tmp6;
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp1 = NULL;
-	started = (_tmp1 = dvb_recording_get_start (self, &_tmp0), started_length1 = _tmp0, _tmp1);
+	started = (_tmp1 = dvb_recording_get_start (self, &_tmp0), started_length1 = _tmp0, started_size = started_length1, _tmp1);
 	_tmp2 = NULL;
-	if ((self->priv->_Name == NULL)) {
+	if (self->priv->_Name == NULL) {
 		_tmp2 = "";
 	} else {
 		_tmp2 = self->priv->_Name;
 	}
 	_tmp3 = NULL;
-	if ((self->priv->_Description == NULL)) {
+	if (self->priv->_Description == NULL) {
 		_tmp3 = "";
 	} else {
 		_tmp3 = self->priv->_Description;
@@ -132,7 +134,7 @@ char* dvb_recording_serialize (DVBRecording* self) {
 	_tmp4 = NULL;
 	_tmp5 = NULL;
 	_tmp6 = NULL;
-	return (_tmp6 = (_tmp5 = g_strdup_printf ("%u\n%u\n%s\n%s\n%s\n%u-%u-%u %u:%u\n%lld", (guint) self->priv->_Id, self->priv->_ChannelSid, _tmp4 = g_file_get_path (self->priv->_Location), _tmp2, _tmp3, started[0], started[1], started[2], started[3], started[4], self->priv->_Length), _tmp4 = (g_free (_tmp4), NULL), _tmp5), started = (g_free (started), NULL), _tmp6);
+	return (_tmp6 = (_tmp5 = g_strdup_printf ("%u\n%u\n%s\n%u-%u-%u %u:%u\n%lld\n%s\n%s", (guint) self->priv->_Id, self->priv->_ChannelSid, _tmp4 = g_file_get_path (self->priv->_Location), started[0], started[1], started[2], started[3], started[4], self->priv->_Length, _tmp2, _tmp3), _tmp4 = (g_free (_tmp4), NULL), _tmp5), started = (g_free (started), NULL), _tmp6);
 }
 
 
@@ -140,15 +142,17 @@ char* dvb_recording_serialize (DVBRecording* self) {
 DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 	GError * inner_error;
 	char* contents;
-	char** _tmp1;
+	char** _tmp2;
+	gint fields_size;
 	gint fields_length1;
+	char** _tmp1;
 	char** fields;
 	DVBRecording* rec;
 	char* field;
 	gint i;
-	char* _tmp3;
-	const char* _tmp2;
-	DVBRecording* _tmp7;
+	char* _tmp4;
+	const char* _tmp3;
+	DVBRecording* _tmp12;
 	g_return_val_if_fail (file != NULL, NULL);
 	inner_error = NULL;
 	contents = dvb_utils_read_file_contents (file, &inner_error);
@@ -161,14 +165,15 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 		_tmp0 = NULL;
 		return (_tmp0 = NULL, contents = (g_free (contents), NULL), _tmp0);
 	}
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	fields = (_tmp1 = g_strsplit (contents, "\n", 0), fields_length1 = -1, _tmp1);
+	fields = (_tmp2 = _tmp1 = g_strsplit (contents, "\n", 7), fields_length1 = _vala_array_length (_tmp1), fields_size = fields_length1, _tmp2);
 	rec = dvb_recording_new ();
 	field = NULL;
 	i = 0;
+	_tmp4 = NULL;
 	_tmp3 = NULL;
-	_tmp2 = NULL;
-	while ((field = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), field = (g_free (field), NULL), _tmp3)) != NULL) {
+	while ((field = (_tmp4 = (_tmp3 = fields[i], (_tmp3 == NULL) ? NULL : g_strdup (_tmp3)), field = (g_free (field), NULL), _tmp4)) != NULL) {
 		switch (i) {
 			case 0:
 			{
@@ -185,31 +190,14 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 				if (_vala_strcmp0 (field, "") == 0) {
 					dvb_recording_set_Location (rec, NULL);
 				} else {
-					GFile* _tmp4;
-					_tmp4 = NULL;
-					dvb_recording_set_Location (rec, _tmp4 = g_file_new_for_path (field));
-					(_tmp4 == NULL) ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL));
+					GFile* _tmp5;
+					_tmp5 = NULL;
+					dvb_recording_set_Location (rec, _tmp5 = g_file_new_for_path (field));
+					(_tmp5 == NULL) ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL));
 				}
 				break;
 			}
 			case 3:
-			{
-				const char* _tmp5;
-				_tmp5 = NULL;
-				if ((_vala_strcmp0 (field, "") == 0)) {
-					_tmp5 = NULL;
-				} else {
-					_tmp5 = field;
-				}
-				dvb_recording_set_Name (rec, _tmp5);
-				break;
-			}
-			case 4:
-			{
-				dvb_recording_set_Description (rec, field);
-				break;
-			}
-			case 5:
 			{
 				{
 					gint year;
@@ -217,31 +205,74 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 					gint day;
 					gint hour;
 					gint minute;
-					struct tm _tmp6 = {0};
+					gboolean _tmp6;
+					gboolean _tmp7;
+					gboolean _tmp8;
+					gboolean _tmp9;
 					year = 0;
 					month = 0;
 					day = 0;
 					hour = 0;
 					minute = 0;
 					sscanf (field, "%d-%d-%d %d:%d", &year, &month, &day, &hour, &minute, NULL);
-					dvb_recording_set_StartTime (rec, (_tmp6 = dvb_utils_create_time (year, month, day, hour, minute, 0), &_tmp6));
+					_tmp6 = FALSE;
+					_tmp7 = FALSE;
+					_tmp8 = FALSE;
+					_tmp9 = FALSE;
+					if (year >= 1900) {
+						_tmp9 = month >= 1;
+					} else {
+						_tmp9 = FALSE;
+					}
+					if (_tmp9) {
+						_tmp8 = day >= 1;
+					} else {
+						_tmp8 = FALSE;
+					}
+					if (_tmp8) {
+						_tmp7 = hour >= 0;
+					} else {
+						_tmp7 = FALSE;
+					}
+					if (_tmp7) {
+						_tmp6 = minute >= 0;
+					} else {
+						_tmp6 = FALSE;
+					}
+					if (_tmp6) {
+						struct tm _tmp10 = {0};
+						dvb_recording_set_StartTime (rec, (_tmp10 = dvb_utils_create_time (year, month, day, hour, minute, 0), &_tmp10));
+					}
 					break;
 				}
 			}
-			case 6:
+			case 4:
 			{
 				dvb_recording_set_Length (rec, (gint64) atoi (field));
 				break;
 			}
+			case 5:
+			{
+				const char* _tmp11;
+				_tmp11 = NULL;
+				if (_vala_strcmp0 (field, "") == 0) {
+					_tmp11 = NULL;
+				} else {
+					_tmp11 = field;
+				}
+				dvb_recording_set_Name (rec, _tmp11);
+				break;
+			}
 			default:
 			{
+				dvb_recording_set_Description (rec, field);
 				break;
 			}
 		}
 		i++;
 	}
-	_tmp7 = NULL;
-	return (_tmp7 = rec, contents = (g_free (contents), NULL), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), field = (g_free (field), NULL), _tmp7);
+	_tmp12 = NULL;
+	return (_tmp12 = rec, contents = (g_free (contents), NULL), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), field = (g_free (field), NULL), _tmp12);
 }
 
 
@@ -365,6 +396,7 @@ void dvb_recording_set_Length (DVBRecording* self, gint64 value) {
 
 static void dvb_recording_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBRecording * self;
+	gpointer boxed;
 	self = DVB_RECORDING (object);
 	switch (property_id) {
 		case DVB_RECORDING_ID:
@@ -464,20 +496,28 @@ GType dvb_recording_get_type (void) {
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
