@@ -46,11 +46,11 @@ static gboolean dvb_satellite_channel_real_is_valid (DVBChannel* base) {
 		} else {
 			_tmp2 = _vala_strcmp0 (self->priv->_Polarization, "h") == 0;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	} else {
 		_tmp0 = FALSE;
 	}
-	return (_tmp0);
+	return _tmp0;
 }
 
 
