@@ -41,7 +41,6 @@ struct _DVBIDBusSatelliteScannerIface {
 	void (*Run) (DVBIDBusSatelliteScanner* self);
 	void (*Destroy) (DVBIDBusSatelliteScanner* self);
 	gboolean (*WriteChannelsToFile) (DVBIDBusSatelliteScanner* self, const char* path);
-	guint (*GetQueueSize) (DVBIDBusSatelliteScanner* self);
 	void (*AddScanningData) (DVBIDBusSatelliteScanner* self, guint frequency, const char* polarization, guint symbol_rate);
 	gboolean (*AddScanningDataFromFile) (DVBIDBusSatelliteScanner* self, const char* path);
 };
@@ -59,7 +58,6 @@ struct _DVBSatelliteScannerClass {
 void dvb_id_bus_satellite_scanner_Run (DVBIDBusSatelliteScanner* self);
 void dvb_id_bus_satellite_scanner_Destroy (DVBIDBusSatelliteScanner* self);
 gboolean dvb_id_bus_satellite_scanner_WriteChannelsToFile (DVBIDBusSatelliteScanner* self, const char* path);
-guint dvb_id_bus_satellite_scanner_GetQueueSize (DVBIDBusSatelliteScanner* self);
 void dvb_id_bus_satellite_scanner_AddScanningData (DVBIDBusSatelliteScanner* self, guint frequency, const char* polarization, guint symbol_rate);
 gboolean dvb_id_bus_satellite_scanner_AddScanningDataFromFile (DVBIDBusSatelliteScanner* self, const char* path);
 void dvb_id_bus_satellite_scanner_dbus_register_object (DBusConnection* connection, const char* path, void* object);
