@@ -12,9 +12,9 @@
 
 
 
-static char* bool_to_string (gboolean self);
 static char* string_replace (const char* self, const char* old, const char* replacement);
 static char* string_substring (const char* self, glong offset, glong len);
+static char* bool_to_string (gboolean self);
 struct _DVBScannerPrivate {
 	DVBDevice* _Device;
 	GeeArrayList* new_channels;
@@ -52,15 +52,6 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 static void g_cclosure_user_marshal_VOID__UINT_UINT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
 static void g_cclosure_user_marshal_VOID__UINT_UINT_STRING_STRING_STRING_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
 
-static char* bool_to_string (gboolean self) {
-	if (self) {
-		return g_strdup ("true");
-	} else {
-		return g_strdup ("false");
-	}
-}
-
-
 static char* string_replace (const char* self, const char* old, const char* replacement) {
 	GError * inner_error;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -133,6 +124,15 @@ static char* string_substring (const char* self, glong offset, glong len) {
 }
 
 
+static char* bool_to_string (gboolean self) {
+	if (self) {
+		return g_strdup ("true");
+	} else {
+		return g_strdup ("false");
+	}
+}
+
+
 static void dvb_scanner_real_prepare (DVBScanner* self) {
 	g_return_if_fail (self != NULL);
 	g_critical ("Type `%s' does not implement abstract method `dvb_scanner_prepare'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
@@ -443,7 +443,7 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 	} else {
 		_tmp0 = FALSE;
 	}
-	all_tables = (_tmp0);
+	all_tables = _tmp0;
 	_tmp5 = NULL;
 	_tmp4 = NULL;
 	_tmp3 = NULL;
@@ -491,7 +491,7 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 	gst_element_set_state (self->pipeline, GST_STATE_READY);
 	dvb_scanner_prepare (self);
 	/* Reset PIDs*/
-	dvbsrc = gst_bin_get_by_name ((GST_BIN (self->pipeline)), "dvbsrc");
+	dvbsrc = gst_bin_get_by_name (GST_BIN (self->pipeline), "dvbsrc");
 	g_object_set ((GObject*) dvbsrc, "pids", DVB_SCANNER_BASE_PIDS, NULL);
 	gst_element_set_state (self->pipeline, GST_STATE_PLAYING);
 	self->priv->check_for_lock_event_id = g_timeout_add_seconds ((guint) 5, _dvb_scanner_check_for_lock_gsource_func, self);
@@ -531,7 +531,7 @@ gboolean dvb_scanner_wait_for_tables (DVBScanner* self) {
 	} else {
 		_tmp0 = FALSE;
 	}
-	if (!(_tmp0)) {
+	if (!_tmp0) {
 		gst_element_set_state (self->pipeline, GST_STATE_READY);
 		dvb_scanner_start_scan (self);
 	}
@@ -656,7 +656,7 @@ void dvb_scanner_on_pat_structure (DVBScanner* self, const GstStructure* structu
 	pids = string_substring (new_pids->str, (glong) 0, new_pids->len - 1);
 	g_debug ("Scanner.vala:363: Setting %d pids: %s", gee_collection_get_size ((GeeCollection*) pid_set), pids);
 	/* We want to parse the pmt as well*/
-	dvbsrc = gst_bin_get_by_name ((GST_BIN (self->pipeline)), "dvbsrc");
+	dvbsrc = gst_bin_get_by_name (GST_BIN (self->pipeline), "dvbsrc");
 	g_object_set ((GObject*) dvbsrc, "pids", pids, NULL);
 	self->priv->pat_arrived = TRUE;
 	(pid_set == NULL) ? NULL : (pid_set = (g_object_unref (pid_set), NULL));
@@ -1011,7 +1011,7 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 						char* type;
 						char* _tmp9;
 						_tmp7 = NULL;
-						if ((dvb_channel_get_VideoPID (channel) == 0)) {
+						if (dvb_channel_get_VideoPID (channel) == 0) {
 							_tmp7 = "Radio";
 						} else {
 							_tmp7 = "TV";
