@@ -124,17 +124,17 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		group_type = sqlite3_column_int (statement, 1);
 		type = 0;
 		switch (group_type) {
-			case 0:
+			case 1:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_T;
 				break;
 			}
-			case 1:
+			case 2:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_S;
 				break;
 			}
-			case 2:
+			case 3:
 			{
 				type = DVB_ADAPTER_TYPE_DVB_C;
 				break;
@@ -317,7 +317,7 @@ gboolean dvb_sqlite_config_timers_store_contains_group (DVBSqliteConfigTimersSto
 	while (sqlite3_step (self->priv->contains_group_statement) == SQLITE_ROW) {
 		c = sqlite3_column_int (self->priv->contains_group_statement, 0);
 	}
-	return (c > 0);
+	return c > 0;
 }
 
 
@@ -521,7 +521,7 @@ gboolean dvb_sqlite_config_timers_store_contains_timer (DVBSqliteConfigTimersSto
 	while (sqlite3_step (self->priv->contains_timer_statement) == SQLITE_ROW) {
 		c = sqlite3_column_int (self->priv->contains_timer_statement, 0);
 	}
-	return (c > 0);
+	return c > 0;
 }
 
 
@@ -578,7 +578,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 			return NULL;
 		}
 	}
-	create_tables = (!g_file_query_exists (dbfile, NULL));
+	create_tables = !g_file_query_exists (dbfile, NULL);
 	db = NULL;
 	_tmp4 = NULL;
 	_tmp2 = NULL;
