@@ -73,7 +73,7 @@ static gboolean dvb_sqlite_epg_store_real_add_or_update_event (DVBEPGStore* base
 		return FALSE;
 	}
 	_tmp1 = 0;
-	if ((event->free_ca_mode)) {
+	if (event->free_ca_mode) {
 		_tmp1 = 1;
 	} else {
 		_tmp1 = 0;
@@ -314,7 +314,7 @@ static gboolean dvb_sqlite_epg_store_real_contains_event (DVBEPGStore* base, DVB
 	while (sqlite3_step (self->priv->has_event_statement) == SQLITE_ROW) {
 		c = sqlite3_column_int (self->priv->has_event_statement, 0);
 	}
-	return (c > 0);
+	return c > 0;
 }
 
 
@@ -389,7 +389,7 @@ static DVBEvent* dvb_sqlite_epg_store_create_event_from_statement (DVBSqliteEPGS
 	sscanf (starttime, "%04u-%02u-%02u %02u:%02u:%02u", &event->year, &event->month, &event->day, &event->hour, &event->minute, &event->second, NULL);
 	event->duration = (guint) sqlite3_column_int (statement, 2);
 	event->running_status = (guint) sqlite3_column_int (statement, 3);
-	event->free_ca_mode = (sqlite3_column_int (statement, 4) == 1);
+	event->free_ca_mode = sqlite3_column_int (statement, 4) == 1;
 	/* Duplicate strings*/
 	_tmp0 = NULL;
 	event->name = (_tmp0 = g_strdup_printf ("%s", sqlite3_column_text (statement, 5)), event->name = (g_free (event->name), NULL), _tmp0);
@@ -571,7 +571,7 @@ static sqlite3* dvb_sqlite_epg_store_get_db_handler (void) {
 			return NULL;
 		}
 	}
-	create_tables = (!g_file_query_exists (eventsdb, NULL));
+	create_tables = !g_file_query_exists (eventsdb, NULL);
 	db = NULL;
 	_tmp4 = NULL;
 	_tmp2 = NULL;
