@@ -120,12 +120,12 @@ gboolean dvb_timer_conflicts_with (DVBTimer* self, DVBTimer* t2) {
 		time_t this_end;
 		/* No conflict when this timer ends before other starts*/
 		this_end = dvb_timer_get_end_time_timestamp (self);
-		return (this_end > other_start);
+		return this_end > other_start;
 	} else {
 		time_t other_end;
 		/* No conflict when other timer ends before this starts*/
 		other_end = dvb_timer_get_end_time_timestamp (t2);
-		return (other_end > this_start);
+		return other_end > this_start;
 	}
 }
 
@@ -282,7 +282,7 @@ gboolean dvb_timer_is_start_due (DVBTimer* self) {
 	} else {
 		_tmp3 = FALSE;
 	}
-	return (_tmp3);
+	return _tmp3;
 }
 
 
@@ -328,7 +328,7 @@ gboolean dvb_timer_is_end_due (DVBTimer* self) {
 	} else {
 		_tmp5 = FALSE;
 	}
-	return (_tmp5);
+	return _tmp5;
 }
 
 
@@ -342,7 +342,7 @@ gboolean dvb_timer_has_expired (DVBTimer* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	current_time = (time (&_tmp0), _tmp0);
 	end_time = dvb_timer_get_end_time_timestamp (self);
-	return (end_time < current_time);
+	return end_time < current_time;
 }
 
 
