@@ -15,7 +15,7 @@ G_BEGIN_DECLS
 
 #define DVB_UTILS_BUFFER_SIZE 4096
 const char* dvb_utils_get_nick_from_enum (GType enumtype, gint val);
-gint dvb_utils_get_value_by_name_from_enum (GType enumtype, const char* name);
+gboolean dvb_utils_get_value_by_name_from_enum (GType enumtype, const char* name, gint* evalue);
 const char* dvb_utils_get_name_by_value_from_enum (GType enumtype, gint val);
 void dvb_utils_mkdirs (GFile* directory, GError** error);
 char* dvb_utils_remove_nonalphanums (const char* text);
