@@ -175,7 +175,7 @@ static void dvb_media_factory_on_dvbbasebin_pad_added (DVBMediaFactory* self, Gs
 		GstElement* sink;
 		char* _tmp4;
 		sink_name = g_strdup ("pay0");
-		sink = gst_bin_get_by_name ((GST_BIN (self->priv->dvbrtpbin)), sink_name);
+		sink = gst_bin_get_by_name (GST_BIN (self->priv->dvbrtpbin), sink_name);
 		if (sink == NULL) {
 			g_critical ("MediaFactory.vala:95: No element with name %s", sink_name);
 		} else {
